#include "newmacros.h"
#include "runtime.h"

#define CT_v389	((void*)startLabel+92)
#define FN_LAMBDA371	((void*)startLabel+136)
#define CT_v393	((void*)startLabel+180)
#define CF_LAMBDA371	((void*)startLabel+188)
#define v396	((void*)startLabel+408)
#define CT_v410	((void*)startLabel+648)
#define v413	((void*)startLabel+912)
#define CT_v427	((void*)startLabel+1152)
#define v431	((void*)startLabel+1462)
#define v432	((void*)startLabel+1466)
#define v433	((void*)startLabel+1487)
#define v435	((void*)startLabel+1648)
#define v437	((void*)startLabel+1724)
#define v438	((void*)startLabel+1889)
#define CT_v461	((void*)startLabel+2392)
#define CT_v468	((void*)startLabel+2568)
#define CT_v471	((void*)startLabel+2628)
#define CT_v474	((void*)startLabel+2684)
#define CT_v477	((void*)startLabel+2740)
#define CT_v480	((void*)startLabel+2796)
#define CT_v483	((void*)startLabel+2852)
#define CT_v486	((void*)startLabel+2908)
#define CT_v489	((void*)startLabel+2964)
#define ST_v392	((void*)startLabel+2992)
#define ST_v473	((void*)startLabel+3048)
#define ST_v470	((void*)startLabel+3084)
#define ST_v416	((void*)startLabel+3116)
#define ST_v399	((void*)startLabel+3136)
#define ST_v386	((void*)startLabel+3152)
#define PP_LAMBDA371	((void*)startLabel+3177)
#define PC_LAMBDA371	((void*)startLabel+3177)
#define ST_v391	((void*)startLabel+3177)
#define ST_v441	((void*)startLabel+3208)
#define ST_v465	((void*)startLabel+3224)
#define ST_v482	((void*)startLabel+3244)
#define ST_v488	((void*)startLabel+3260)
#define ST_v485	((void*)startLabel+3276)
#define ST_v476	((void*)startLabel+3300)
#define ST_v479	((void*)startLabel+3316)
#define PS_v478	((void*)startLabel+3336)
#define PS_v475	((void*)startLabel+3348)
#define PS_v481	((void*)startLabel+3360)
#define PS_v487	((void*)startLabel+3372)
#define PS_v484	((void*)startLabel+3384)
#define PS_v466	((void*)startLabel+3396)
#define PS_v464	((void*)startLabel+3408)
#define PS_v451	((void*)startLabel+3420)
#define PS_v452	((void*)startLabel+3432)
#define PS_v448	((void*)startLabel+3444)
#define PS_v457	((void*)startLabel+3456)
#define PS_v442	((void*)startLabel+3468)
#define PS_v450	((void*)startLabel+3480)
#define PS_v455	((void*)startLabel+3492)
#define PS_v458	((void*)startLabel+3504)
#define PS_v446	((void*)startLabel+3516)
#define PS_v460	((void*)startLabel+3528)
#define PS_v447	((void*)startLabel+3540)
#define PS_v453	((void*)startLabel+3552)
#define PS_v440	((void*)startLabel+3564)
#define PS_v454	((void*)startLabel+3576)
#define PS_v444	((void*)startLabel+3588)
#define PS_v445	((void*)startLabel+3600)
#define PS_v459	((void*)startLabel+3612)
#define PS_v449	((void*)startLabel+3624)
#define PS_v422	((void*)startLabel+3636)
#define PS_v417	((void*)startLabel+3648)
#define PS_v424	((void*)startLabel+3660)
#define PS_v426	((void*)startLabel+3672)
#define PS_v421	((void*)startLabel+3684)
#define PS_v415	((void*)startLabel+3696)
#define PS_v423	((void*)startLabel+3708)
#define PS_v419	((void*)startLabel+3720)
#define PS_v420	((void*)startLabel+3732)
#define PS_v425	((void*)startLabel+3744)
#define PS_v405	((void*)startLabel+3756)
#define PS_v400	((void*)startLabel+3768)
#define PS_v407	((void*)startLabel+3780)
#define PS_v409	((void*)startLabel+3792)
#define PS_v404	((void*)startLabel+3804)
#define PS_v398	((void*)startLabel+3816)
#define PS_v406	((void*)startLabel+3828)
#define PS_v402	((void*)startLabel+3840)
#define PS_v403	((void*)startLabel+3852)
#define PS_v408	((void*)startLabel+3864)
#define PS_v388	((void*)startLabel+3876)
#define PS_v385	((void*)startLabel+3888)
#define PS_v387	((void*)startLabel+3900)
#define PS_v469	((void*)startLabel+3912)
#define PS_v472	((void*)startLabel+3924)
#define PS_v390	((void*)startLabel+3936)
extern Node FN_NHC_46Internal_46_95noMethodError[];
extern Node FN_Prelude_46properFraction[];
extern Node FN_Prelude_46RealFrac_46Prelude_46Real[];
extern Node FN_Prelude_46Real_46Prelude_46Num[];
extern Node FN_Prelude_46fromInteger[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Real_46Prelude_46Ord[];
extern Node FN_Prelude_46_60[];
extern Node FN_Prelude_46Integral_46Prelude_46Real[];
extern Node FN_Prelude_46_45[];
extern Node FN_Prelude_46_62[];
extern Node FN_Prelude_46_43[];
extern Node FN_Prelude_46abs[];
extern Node FN_Prelude_46RealFrac_46Prelude_46Fractional[];
extern Node FN_Prelude_46fromRational[];
extern Node FN_Ratio_46_37[];
extern Node CF_Prelude_46Integral_46Prelude_46Integer[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46compare[];
extern Node FN_Prelude_46even[];
extern Node PM_Prelude[];
extern Node PC_Ratio_46_37[];
extern Node PC_NHC_46Internal_46_95apply2[];
extern Node PC_NHC_46Internal_46_95apply1[];
extern Node PC_Prelude_46even[];
extern Node PC_Prelude_46fromRational[];
extern Node PC_Prelude_46compare[];
extern Node PC_Prelude_46_60[];
extern Node PC_Prelude_46_45[];
extern Node PC_Prelude_46_43[];
extern Node PC_Prelude_46abs[];
extern Node PC_Prelude_46fromInteger[];
extern Node PC_Prelude_46Real_46Prelude_46Ord[];
extern Node PC_Prelude_46Real_46Prelude_46Num[];
extern Node PC_Prelude_46Integral_46Prelude_46Real[];
extern Node PC_Prelude_46_62[];
extern Node PC_NHC_46Internal_46_95noMethodError[];

static Node startLabel[] = {
  bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v389)
,};
Node FN_Prelude_46_95_46properFraction[] = {
  bytes2word(ZAP_ARG_I1,ZAP_ARG_I2,NEEDHEAP_I32,PUSH_ARG_I3)
, bytes2word(HEAP_CVAL_P1,7,HEAP_CVAL_N1,7)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, useLabel(PS_v388)
, 0
, 0
, 0
, 0
, useLabel(PS_v387)
, 0
, 0
, 0
, 0
, 0
, useLabel(ST_v386)
,	/* CT_v389: (byte 0) */
  HW(2,3)
, 0
,};
Node F0_Prelude_46_95_46properFraction[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46properFraction),3)
, useLabel(PS_v385)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_LAMBDA371))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95noMethodError))
, bytes2word(0,0,0,0)
, useLabel(CT_v393)
,	/* FN_LAMBDA371: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v392)
, 0
, useLabel(ST_v391)
,	/* CT_v393: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA371: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA371))
, useLabel(PS_v390)
, 0
, 0
, 0
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v410)
,};
Node FN_Prelude_46_95_46floor[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,7,HEAP_CVAL_N1,7)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(1,ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,2,EVAL,NEEDHEAP_P1)
, bytes2word(43,UNPACK,2,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(11,HEAP_CVAL_N1,27,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(HEAP_CADR_N1,32,PUSH_P1,0)
, bytes2word(PUSH_P1,3,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,HEAP_CVAL_P1)
, bytes2word(12,HEAP_CVAL_N1,37,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,13,HEAP_CVAL_N1)
, bytes2word(42,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,ZAP_ARG_I1,ZAP_STACK_P1)
, bytes2word(5,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(2,SLIDE_P1,1,EVAL)
, bytes2word(NEEDHEAP_P1,43,JUMPFALSE,81)
, bytes2word(0,HEAP_CVAL_P1,14,HEAP_CVAL_N1)
, bytes2word(47,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,2,HEAP_CVAL_P1,9)
, bytes2word(HEAP_CVAL_N1,17,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,HEAP_CVAL_P1)
, bytes2word(10,HEAP_CVAL_N1,22,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,11,HEAP_CVAL_N1)
, bytes2word(27,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,HEAP_CADR_N1,53)
, bytes2word(PUSH_P1,0,PUSH_P1,2)
, bytes2word(HEAP_CVAL_P1,14,HEAP_CVAL_N1,47)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(2,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(17,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(15,HEAP_CVAL_N1,58,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(ZAP_ARG_I2,ZAP_STACK_P1,3,EVAL)
,	/* v396: (byte 4) */
  bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
, bytes2word(PUSH_P1,0,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, useLabel(PS_v409)
, 0
, 0
, 0
, 0
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, 1
, useLabel(PS_v408)
, 0
, 0
, 0
, 0
, useLabel(PS_v407)
, 0
, 0
, 0
, 0
, useLabel(PS_v406)
, 0
, 0
, 0
, 0
, CONSTRW(0,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v405)
, 0
, 0
, 0
, 0
, useLabel(PS_v404)
, 0
, 0
, 0
, 0
, useLabel(PS_v403)
, 0
, 0
, 0
, 0
, useLabel(PS_v402)
, 0
, 0
, 0
, 0
, useLabel(PS_v400)
, 0
, 0
, 0
, 0
, 180005
, useLabel(ST_v399)
,	/* CT_v410: (byte 0) */
  HW(9,3)
, 0
,};
Node F0_Prelude_46_95_46floor[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46floor),3)
, useLabel(PS_v398)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46properFraction))
, VAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Real))
, VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Num))
, VAPTAG(useLabel(FN_Prelude_46fromInteger))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Ord))
, VAPTAG(useLabel(FN_Prelude_46_60))
, VAPTAG(useLabel(FN_Prelude_46Integral_46Prelude_46Real))
, VAPTAG(useLabel(FN_Prelude_46_45))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v427)
,};
Node FN_Prelude_46_95_46ceiling[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,7,HEAP_CVAL_N1,7)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(1,ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,2,EVAL,NEEDHEAP_P1)
, bytes2word(43,UNPACK,2,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(11,HEAP_CVAL_N1,27,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(HEAP_CADR_N1,32,PUSH_P1,0)
, bytes2word(PUSH_P1,3,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,HEAP_CVAL_P1)
, bytes2word(12,HEAP_CVAL_N1,37,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,13,HEAP_CVAL_N1)
, bytes2word(42,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,ZAP_ARG_I1,ZAP_STACK_P1)
, bytes2word(5,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(2,SLIDE_P1,1,EVAL)
, bytes2word(NEEDHEAP_P1,43,JUMPFALSE,81)
, bytes2word(0,HEAP_CVAL_P1,14,HEAP_CVAL_N1)
, bytes2word(47,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,2,HEAP_CVAL_P1,9)
, bytes2word(HEAP_CVAL_N1,17,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,HEAP_CVAL_P1)
, bytes2word(10,HEAP_CVAL_N1,22,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,11,HEAP_CVAL_N1)
, bytes2word(27,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,HEAP_CADR_N1,53)
, bytes2word(PUSH_P1,0,PUSH_P1,2)
, bytes2word(HEAP_CVAL_P1,14,HEAP_CVAL_N1,47)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(2,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(17,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(15,HEAP_CVAL_N1,58,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(ZAP_ARG_I2,ZAP_STACK_P1,3,EVAL)
,	/* v413: (byte 4) */
  bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
, bytes2word(PUSH_P1,0,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, useLabel(PS_v426)
, 0
, 0
, 0
, 0
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, 1
, useLabel(PS_v425)
, 0
, 0
, 0
, 0
, useLabel(PS_v424)
, 0
, 0
, 0
, 0
, useLabel(PS_v423)
, 0
, 0
, 0
, 0
, CONSTRW(0,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v422)
, 0
, 0
, 0
, 0
, useLabel(PS_v421)
, 0
, 0
, 0
, 0
, useLabel(PS_v420)
, 0
, 0
, 0
, 0
, useLabel(PS_v419)
, 0
, 0
, 0
, 0
, useLabel(PS_v417)
, 0
, 0
, 0
, 0
, 170005
, useLabel(ST_v416)
,	/* CT_v427: (byte 0) */
  HW(9,3)
, 0
,};
Node F0_Prelude_46_95_46ceiling[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46ceiling),3)
, useLabel(PS_v415)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46properFraction))
, VAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Real))
, VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Num))
, VAPTAG(useLabel(FN_Prelude_46fromInteger))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Ord))
, VAPTAG(useLabel(FN_Prelude_46_62))
, VAPTAG(useLabel(FN_Prelude_46Integral_46Prelude_46Real))
, VAPTAG(useLabel(FN_Prelude_46_43))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v461)
,};
Node FN_Prelude_46_95_46round[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,7,HEAP_CVAL_N1,7)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(1,ZAP_ARG_I3,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,2,EVAL,NEEDHEAP_P1)
, bytes2word(121,UNPACK,2,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,HEAP_CVAL_P1)
, bytes2word(9,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(HEAP_CVAL_P1,11,HEAP_CVAL_N1,27)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,12,HEAP_CVAL_N1)
, bytes2word(32,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,HEAP_I1,HEAP_CVAL_P1)
, bytes2word(13,HEAP_CVAL_N1,37,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_P1,14,HEAP_CVAL_N1,42)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,15,HEAP_CVAL_N1)
, bytes2word(47,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,16,HEAP_CADR_N1,53)
, bytes2word(HEAP_CADR_N1,59,HEAP_CVAL_P1,12)
, bytes2word(HEAP_CVAL_N1,32,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,19,HEAP_OFF_N1)
, bytes2word(14,PUSH_HEAP,HEAP_CVAL_P1,17)
, bytes2word(HEAP_CVAL_N1,64,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,63,HEAP_OFF_N1)
, bytes2word(40,HEAP_OFF_N1,14,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,18,HEAP_CVAL_N1)
, bytes2word(69,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(12,HEAP_CVAL_N1,32,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(HEAP_CADR_N1,74,PUSH_P1,0)
, bytes2word(PUSH_P1,2,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,HEAP_CVAL_P1)
, bytes2word(19,HEAP_CVAL_N1,79,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,20,HEAP_CVAL_N1)
, bytes2word(84,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,ZAP_STACK_P1,3)
, bytes2word(EVAL,NEEDHEAP_I32,APPLY,2)
, bytes2word(SLIDE_P1,2,EVAL,NEEDHEAP_P1)
, bytes2word(43,TABLESWITCH,3,NOP)
, bytes2word(TOP(6),BOT(6),TOP(10),BOT(10))
,	/* v431: (byte 2) */
  bytes2word(TOP(268),BOT(268),POP_I1,PUSH_P1)
,	/* v432: (byte 2) */
  bytes2word(0,RETURN_EVAL,POP_I1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,21,HEAP_CVAL_N1,89)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(2,HEAP_I1,EVAL,NEEDHEAP_P1)
, bytes2word(43,JUMPFALSE,5,0)
,	/* v433: (byte 3) */
  bytes2word(PUSH_P1,0,RETURN_EVAL,HEAP_CVAL_P1)
, bytes2word(8,HEAP_CVAL_N1,12,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,18,HEAP_CVAL_N1)
, bytes2word(69,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(12,HEAP_CVAL_N1,32,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(HEAP_CADR_N1,74,PUSH_P1,0)
, bytes2word(PUSH_P1,3,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,HEAP_CVAL_P1)
, bytes2word(19,HEAP_CVAL_N1,79,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,22,HEAP_CVAL_N1)
, bytes2word(94,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,EVAL,NEEDHEAP_I32)
, bytes2word(APPLY,2,SLIDE_P1,1)
, bytes2word(EVAL,NEEDHEAP_P1,43,JUMPFALSE)
, bytes2word(80,0,HEAP_CVAL_P1,23)
, bytes2word(HEAP_CVAL_N1,99,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,2,HEAP_CVAL_P1)
, bytes2word(9,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(HEAP_CVAL_P1,18,HEAP_CVAL_N1,69)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,PUSH_HEAP,HEAP_CVAL_P1,12)
, bytes2word(HEAP_CVAL_N1,32,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,HEAP_CADR_N1)
, bytes2word(53,PUSH_P1,0,PUSH_P1)
, bytes2word(2,HEAP_CVAL_P1,23,HEAP_CVAL_N1)
, bytes2word(99,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,2,HEAP_CVAL_P1,9)
, bytes2word(HEAP_CVAL_N1,17,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,ZAP_STACK_P1,3,EVAL)
,	/* v435: (byte 4) */
  bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
, bytes2word(HEAP_CVAL_P1,23,HEAP_CVAL_N1,99)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(2,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(17,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,HEAP_CVAL_P1,18)
, bytes2word(HEAP_CVAL_N1,69,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,12,HEAP_CVAL_N1,32)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CADR_N1,53,PUSH_P1)
, bytes2word(0,PUSH_P1,2,HEAP_CVAL_P1)
, bytes2word(23,HEAP_CVAL_N1,99,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,2)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,PUSH_HEAP,HEAP_CVAL_P1,24)
, bytes2word(HEAP_CVAL_N1,104,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,EVAL)
,	/* v437: (byte 4) */
  bytes2word(NEEDHEAP_I32,APPLY,2,RETURN_EVAL)
, bytes2word(POP_I1,HEAP_CVAL_P1,8,HEAP_CVAL_N1)
, bytes2word(12,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,1,HEAP_CVAL_P1,9)
, bytes2word(HEAP_CVAL_N1,17,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,HEAP_CVAL_P1)
, bytes2word(18,HEAP_CVAL_N1,69,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,12,HEAP_CVAL_N1)
, bytes2word(32,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,HEAP_CADR_N1,74)
, bytes2word(PUSH_P1,0,PUSH_P1,3)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_P1,19,HEAP_CVAL_N1)
, bytes2word(79,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(22,HEAP_CVAL_N1,94,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(ZAP_ARG_I1,ZAP_STACK_P1,5,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,2,SLIDE_P1)
, bytes2word(1,EVAL,NEEDHEAP_P1,43)
, bytes2word(JUMPFALSE,80,0,HEAP_CVAL_P1)
, bytes2word(23,HEAP_CVAL_N1,99,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,2)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(11,HEAP_CVAL_P1,18,HEAP_CVAL_N1)
, bytes2word(69,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(12,HEAP_CVAL_N1,32,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(HEAP_CADR_N1,53,PUSH_P1,0)
, bytes2word(PUSH_P1,2,HEAP_CVAL_P1,23)
, bytes2word(HEAP_CVAL_N1,99,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,2,HEAP_CVAL_P1)
, bytes2word(9,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,ZAP_STACK_P1,3)
, bytes2word(EVAL,NEEDHEAP_I32,APPLY,2)
,	/* v438: (byte 1) */
  bytes2word(RETURN_EVAL,HEAP_CVAL_P1,23,HEAP_CVAL_N1)
, bytes2word(99,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_ARG,2,HEAP_CVAL_P1,9)
, bytes2word(HEAP_CVAL_N1,17,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,11,HEAP_CVAL_P1)
, bytes2word(18,HEAP_CVAL_N1,69,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,12,HEAP_CVAL_N1)
, bytes2word(32,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,HEAP_CADR_N1,53)
, bytes2word(PUSH_P1,0,PUSH_P1,2)
, bytes2word(HEAP_CVAL_P1,23,HEAP_CVAL_N1,99)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(2,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(17,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,11,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(24,HEAP_CVAL_N1,104,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,11)
, bytes2word(ZAP_ARG_I2,ZAP_STACK_P1,4,ZAP_STACK_P1)
, bytes2word(3,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v460)
, 0
, 0
, 0
, 0
, useLabel(PS_v459)
, 0
, 0
, 0
, 0
, useLabel(PS_v458)
, 0
, 0
, 0
, 0
, useLabel(PS_v457)
, 0
, 0
, 0
, 0
, useLabel(PS_v455)
, 0
, 0
, 0
, 0
, useLabel(PS_v454)
, 0
, 0
, 0
, 0
, CONSTRW(0,0)
, 0
, 0
, 0
, 0
, useLabel(PS_v453)
, 0
, 0
, 0
, 0
, useLabel(PS_v452)
, 0
, 0
, 0
, 0
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, 2
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, 1
, useLabel(PS_v451)
, 0
, 0
, 0
, 0
, useLabel(PS_v450)
, 0
, 0
, 0
, 0
, useLabel(PS_v449)
, 0
, 0
, 0
, 0
, useLabel(PS_v448)
, 0
, 0
, 0
, 0
, useLabel(PS_v447)
, 0
, 0
, 0
, 0
, useLabel(PS_v446)
, 0
, 0
, 0
, 0
, useLabel(PS_v445)
, 0
, 0
, 0
, 0
, useLabel(PS_v444)
, 0
, 0
, 0
, 0
, useLabel(PS_v442)
, 0
, 0
, 0
, 0
, 110005
, useLabel(ST_v441)
,	/* CT_v461: (byte 0) */
  HW(18,3)
, 0
,};
Node F0_Prelude_46_95_46round[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46round),3)
, useLabel(PS_v440)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46properFraction))
, VAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Real))
, VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Num))
, VAPTAG(useLabel(FN_Prelude_46_45))
, VAPTAG(useLabel(FN_Prelude_46abs))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, VAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Fractional))
, VAPTAG(useLabel(FN_Prelude_46fromRational))
, VAPTAG(useLabel(FN_Ratio_46_37))
, useLabel(CF_Prelude_46Integral_46Prelude_46Integer)
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, VAPTAG(useLabel(FN_Prelude_46fromInteger))
, VAPTAG(useLabel(FN_Prelude_46Real_46Prelude_46Ord))
, VAPTAG(useLabel(FN_Prelude_46compare))
, VAPTAG(useLabel(FN_Prelude_46even))
, VAPTAG(useLabel(FN_Prelude_46_60))
, VAPTAG(useLabel(FN_Prelude_46Integral_46Prelude_46Real))
, VAPTAG(useLabel(FN_Prelude_46_43))
, bytes2word(3,0,2,1)
, bytes2word(1,2,0,3)
, useLabel(CT_v468)
,};
Node FN_Prelude_46_95_46truncate[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I3,PUSH_ARG_I2,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,7,HEAP_CVAL_N1,7)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_ARG)
, bytes2word(1,ZAP_ARG_I1,ZAP_ARG_I2,ZAP_ARG_I3)
, bytes2word(EVAL,NEEDHEAP_I32,APPLY,2)
, bytes2word(EVAL,UNPACK,2,PUSH_P1)
, bytes2word(0,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v466)
, 0
, 0
, 0
, 0
, 100005
, useLabel(ST_v465)
,	/* CT_v468: (byte 0) */
  HW(1,3)
, 0
,};
Node F0_Prelude_46_95_46truncate[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46truncate),3)
, useLabel(PS_v464)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46properFraction))
, bytes2word(1,0,0,1)
, useLabel(CT_v471)
,};
Node FN_Prelude_46RealFrac_46Prelude_46Real[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v470)
,	/* CT_v471: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46RealFrac_46Prelude_46Real[] = {
  CAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Real),1)
, useLabel(PS_v469)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v474)
,};
Node FN_Prelude_46RealFrac_46Prelude_46Fractional[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v473)
,	/* CT_v474: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46RealFrac_46Prelude_46Fractional[] = {
  CAPTAG(useLabel(FN_Prelude_46RealFrac_46Prelude_46Fractional),1)
, useLabel(PS_v472)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v477)
,};
Node FN_Prelude_46round[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,3)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v476)
,	/* CT_v477: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46round[] = {
  CAPTAG(useLabel(FN_Prelude_46round),1)
, useLabel(PS_v475)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v480)
,};
Node FN_Prelude_46truncate[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,4)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v479)
,	/* CT_v480: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46truncate[] = {
  CAPTAG(useLabel(FN_Prelude_46truncate),1)
, useLabel(PS_v478)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v483)
,};
Node FN_Prelude_46ceiling[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,5)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v482)
,	/* CT_v483: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46ceiling[] = {
  CAPTAG(useLabel(FN_Prelude_46ceiling),1)
, useLabel(PS_v481)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v486)
,};
Node FN_Prelude_46properFraction[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,6)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v485)
,	/* CT_v486: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46properFraction[] = {
  CAPTAG(useLabel(FN_Prelude_46properFraction),1)
, useLabel(PS_v484)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v489)
,};
Node FN_Prelude_46floor[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,7)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 50034
, useLabel(ST_v488)
,	/* CT_v489: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46floor[] = {
  CAPTAG(useLabel(FN_Prelude_46floor),1)
, useLabel(PS_v487)
, 0
, 0
, 0
,	/* ST_v392: (byte 0) */
  bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,112)
, bytes2word(114,111,112,101)
, bytes2word(114,70,114,97)
, bytes2word(99,116,105,111)
, bytes2word(110,0,0,0)
,};
Node PP_Prelude_46RealFrac_46Prelude_46Fractional[] = {
 };
Node PC_Prelude_46RealFrac_46Prelude_46Fractional[] = {
 	/* ST_v473: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(82,101,97,108)
, bytes2word(70,114,97,99)
, bytes2word(46,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,70,114,97)
, bytes2word(99,116,105,111)
, bytes2word(110,97,108,0)
,};
Node PP_Prelude_46RealFrac_46Prelude_46Real[] = {
 };
Node PC_Prelude_46RealFrac_46Prelude_46Real[] = {
 	/* ST_v470: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(82,101,97,108)
, bytes2word(70,114,97,99)
, bytes2word(46,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,82,101,97)
, bytes2word(108,0,0,0)
,};
Node PP_Prelude_46_95_46ceiling[] = {
 };
Node PC_Prelude_46_95_46ceiling[] = {
 	/* ST_v416: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,99,101)
, bytes2word(105,108,105,110)
, bytes2word(103,0,0,0)
,};
Node PP_Prelude_46_95_46floor[] = {
 };
Node PC_Prelude_46_95_46floor[] = {
 	/* ST_v399: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,102,108)
, bytes2word(111,111,114,0)
,};
Node PP_Prelude_46_95_46properFraction[] = {
 };
Node PC_Prelude_46_95_46properFraction[] = {
 	/* ST_v386: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,112,114)
, bytes2word(111,112,101,114)
, bytes2word(70,114,97,99)
, bytes2word(116,105,111,110)
,	/* PP_LAMBDA371: (byte 1) */
 	/* PC_LAMBDA371: (byte 1) */
 	/* ST_v391: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(46,95,46,112)
, bytes2word(114,111,112,101)
, bytes2word(114,70,114,97)
, bytes2word(99,116,105,111)
, bytes2word(110,58,110,111)
, bytes2word(112,111,115,0)
,};
Node PP_Prelude_46_95_46round[] = {
 };
Node PC_Prelude_46_95_46round[] = {
 	/* ST_v441: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,114,111)
, bytes2word(117,110,100,0)
,};
Node PP_Prelude_46_95_46truncate[] = {
 };
Node PC_Prelude_46_95_46truncate[] = {
 	/* ST_v465: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,116,114)
, bytes2word(117,110,99,97)
, bytes2word(116,101,0,0)
,};
Node PP_Prelude_46ceiling[] = {
 };
Node PC_Prelude_46ceiling[] = {
 	/* ST_v482: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(99,101,105,108)
, bytes2word(105,110,103,0)
,};
Node PP_Prelude_46floor[] = {
 };
Node PC_Prelude_46floor[] = {
 	/* ST_v488: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(102,108,111,111)
, bytes2word(114,0,0,0)
,};
Node PP_Prelude_46properFraction[] = {
 };
Node PC_Prelude_46properFraction[] = {
 	/* ST_v485: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(112,114,111,112)
, bytes2word(101,114,70,114)
, bytes2word(97,99,116,105)
, bytes2word(111,110,0,0)
,};
Node PP_Prelude_46round[] = {
 };
Node PC_Prelude_46round[] = {
 	/* ST_v476: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(114,111,117,110)
, bytes2word(100,0,0,0)
,};
Node PP_Prelude_46truncate[] = {
 };
Node PC_Prelude_46truncate[] = {
 	/* ST_v479: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(116,114,117,110)
, bytes2word(99,97,116,101)
, bytes2word(0,0,0,0)
,	/* PS_v478: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46truncate)
, useLabel(PC_Prelude_46truncate)
,	/* PS_v475: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46round)
, useLabel(PC_Prelude_46round)
,	/* PS_v481: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46ceiling)
, useLabel(PC_Prelude_46ceiling)
,	/* PS_v487: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46floor)
, useLabel(PC_Prelude_46floor)
,	/* PS_v484: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46properFraction)
, useLabel(PC_Prelude_46properFraction)
,	/* PS_v466: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46truncate)
, useLabel(PC_Prelude_46properFraction)
,	/* PS_v464: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46truncate)
, useLabel(PC_Prelude_46_95_46truncate)
,	/* PS_v451: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Ratio_46_37)
,	/* PS_v452: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_NHC_46Internal_46_95apply2)
,	/* PS_v448: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_NHC_46Internal_46_95apply1)
,	/* PS_v457: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46even)
,	/* PS_v442: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46properFraction)
,	/* PS_v450: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46fromRational)
,	/* PS_v455: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46compare)
,	/* PS_v458: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46_60)
,	/* PS_v446: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46_45)
,	/* PS_v460: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46_43)
,	/* PS_v447: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46abs)
,	/* PS_v453: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46fromInteger)
,	/* PS_v440: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46_95_46round)
,	/* PS_v454: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
,	/* PS_v444: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
,	/* PS_v445: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46Real_46Prelude_46Num)
,	/* PS_v459: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46Integral_46Prelude_46Real)
,	/* PS_v449: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46round)
, useLabel(PC_Prelude_46RealFrac_46Prelude_46Fractional)
,	/* PS_v422: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_NHC_46Internal_46_95apply1)
,	/* PS_v417: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46properFraction)
,	/* PS_v424: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46_62)
,	/* PS_v426: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46_43)
,	/* PS_v421: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46fromInteger)
,	/* PS_v415: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46_95_46ceiling)
,	/* PS_v423: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
,	/* PS_v419: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
,	/* PS_v420: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46Real_46Prelude_46Num)
,	/* PS_v425: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46ceiling)
, useLabel(PC_Prelude_46Integral_46Prelude_46Real)
,	/* PS_v405: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_NHC_46Internal_46_95apply1)
,	/* PS_v400: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46properFraction)
,	/* PS_v407: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46_60)
,	/* PS_v409: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46_45)
,	/* PS_v404: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46fromInteger)
,	/* PS_v398: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46_95_46floor)
,	/* PS_v406: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46Real_46Prelude_46Ord)
,	/* PS_v402: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
,	/* PS_v403: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46Real_46Prelude_46Num)
,	/* PS_v408: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46floor)
, useLabel(PC_Prelude_46Integral_46Prelude_46Real)
,	/* PS_v388: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46properFraction)
, useLabel(PC_NHC_46Internal_46_95noMethodError)
,	/* PS_v385: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46properFraction)
, useLabel(PC_Prelude_46_95_46properFraction)
,	/* PS_v387: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46properFraction)
, useLabel(PC_LAMBDA371)
,	/* PS_v469: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46RealFrac_46Prelude_46Real)
, useLabel(PC_Prelude_46RealFrac_46Prelude_46Real)
,	/* PS_v472: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46RealFrac_46Prelude_46Fractional)
, useLabel(PC_Prelude_46RealFrac_46Prelude_46Fractional)
,	/* PS_v390: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_LAMBDA371)
, useLabel(PC_LAMBDA371)
,};
